@@ -28,6 +28,7 @@ from collections import MutableMapping, OrderedDict
 from functools import total_ordering
 from contextlib import contextmanager
 import io
+import threading
 
 _ = lambda x: x
 from calculate.lib.cl_lang import setLocalTranslate
@@ -51,8 +52,10 @@ def _urlopen(fn, timeout=None):
     else:
         f = opener.open(fn)
     yield f
-    f.close()
 
+    t = threading.Thread(target=f.close)
+    t.daemon = True
+    t.start()
 
 class BinhostsBase(Cachable):
     class BinhostStatus:
